SystemOrganization addCategory: #'Phidget-Examples'!

Object subclass: #PhdExIfKitLED
	instanceVariableNames: 'ifKit running'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-Examples'!

!PhdExIfKitLED commentStamp: 'pt 7/6/2009 16:54' prior: 0!
This is an example for the usage of an InterfaceKit (ifKit).
We expect that there are LED connected to the digital output of the ifKit.

execute this in a workspace:
	led := PhdExIfKitLED new. "creates a new LEDExample"
	led start.				"starts the animation - opens a connection to the ifKit"
	led stop.				"stops the animation - closes the connection - recommended if you want to use this Phidget later. If the connection stays open, the Phidget can not be used somewhere else."!

!PhdExIfKitLED methodsFor: 'initialize' stamp: 'pt 6/30/2009 11:12'!
initialize

	super initialize.
	ifKit := PhdCrInterfaceKit new.! !

!PhdExIfKitLED methodsFor: 'events' stamp: 'fs 7/24/2009 15:28'!
process

	[running] whileTrue: [
		ifKit outputs size = 0 ifFalse: [
			self setLEDState].
		(Delay forMilliseconds: self waitTime) wait]! !

!PhdExIfKitLED methodsFor: 'toggle state' stamp: 'fs 7/24/2009 15:30'!
setLEDState

	self toggle: {(1 to: ifKit outputs size) atRandom}.! !

!PhdExIfKitLED methodsFor: 'toggle state' stamp: 'fs 7/24/2009 15:30'!
start

	ifKit openAny.
	running := true.
	[self process] fork.! !

!PhdExIfKitLED methodsFor: 'toggle state' stamp: 'fs 7/24/2009 15:30'!
stop

	running := false.
	self turnAllOff.
	ifKit close.! !

!PhdExIfKitLED methodsFor: 'toggle state' stamp: 'fs 7/24/2009 15:32'!
toggle: anArray
	"toggle state if needed for all led"
	
	anArray do: [: i |
		(ifKit outputs at: i) value: (ifKit outputs at: i) value not]! !

!PhdExIfKitLED methodsFor: 'toggle state' stamp: 'fs 7/24/2009 15:32'!
turnAllOff

	(1 to: ifKit outputs size) do: [:i | (ifKit outputs at: i) value: false].! !

!PhdExIfKitLED methodsFor: 'toggle state' stamp: 'fs 7/24/2009 15:33'!
turnAllOn

	(1 to: ifKit outputs size) do: [:i | (ifKit outputs at: i) value: true].! !

!PhdExIfKitLED methodsFor: 'toggle state' stamp: 'fs 7/24/2009 15:33'!
turnOff: anArray

	anArray do: [:i | (ifKit outputs at: i) value: false].! !

!PhdExIfKitLED methodsFor: 'toggle state' stamp: 'fs 7/24/2009 15:33'!
turnOn: anArray

	anArray do: [:i | (ifKit outputs at: i) value: true].! !

!PhdExIfKitLED methodsFor: 'accessing' stamp: 'fs 7/24/2009 15:27'!
waitTime

	^ 200! !

PhdExIfKitLED subclass: #PhdExIfKitLEDCircles
	instanceVariableNames: 'state'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-Examples'!

!PhdExIfKitLEDCircles methodsFor: 'initialize' stamp: 'fs 7/24/2009 15:38'!
initialize

	super initialize.
	state := #1.! !

!PhdExIfKitLEDCircles methodsFor: 'toggle state' stamp: 'fs 7/24/2009 15:38'!
setLEDState

	self turnAllOff.
	state =  1 ifTrue: [                           state :=  2. ^ self].
	state =  2 ifTrue: [self turnOn: {1. 4. 5. 8}. state :=  3. ^ self].
	state =  3 ifTrue: [self turnOn: {2. 3. 6. 7}. state :=  1. ^ self].! !

!PhdExIfKitLEDCircles methodsFor: 'accessing' stamp: 'fs 7/24/2009 15:38'!
waitTime

	^ 150! !

PhdExIfKitLED subclass: #PhdExIfKitLEDNothing
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-Examples'!

!PhdExIfKitLEDNothing commentStamp: 'pt 7/6/2009 16:57' prior: 0!
Does nothing, but turn all LEDs on. This may be used for own experiments. Edit setLEDstate to define what happens every <self waitTime> milliseconds. (You may also edit my method waitTime ;))

This example is based on PhdExIfKitLED. Have a look on the comment of that class for further information.!

!PhdExIfKitLEDNothing methodsFor: 'toggle state' stamp: 'pt 7/1/2009 12:01'!
setLEDState
	self turnAllOn.! !

!PhdExIfKitLEDNothing methodsFor: 'accessing' stamp: 'fs 7/24/2009 15:38'!
waitTime

	^ 1000! !

PhdExIfKitLED subclass: #PhdExIfKitLEDSpiral
	instanceVariableNames: 'state'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-Examples'!

!PhdExIfKitLEDSpiral commentStamp: 'pt 7/6/2009 16:55' prior: 0!
Makes the LEDs flash in a spiral.

This class expects the LED ordered as the following:
    4
    3
8 7   6 5
    2
    1

This example is based on PhdExIfKitLED. Have a look on the comment of that class for further information.!

!PhdExIfKitLEDSpiral methodsFor: 'initialize' stamp: 'pt 6/30/2009 12:01'!
initialize
	super initialize.
	state := #1.! !

!PhdExIfKitLEDSpiral methodsFor: 'toggle state' stamp: 'pt 6/30/2009 12:05'!
setLEDState
	
	state =  1 ifTrue: [self turnOn: {1.}. state :=  2. ^ self].
	state =  2 ifTrue: [self turnOn: {8.}. state :=  3. ^ self].
	state =  3 ifTrue: [self turnOn: {4.}. state :=  4. ^ self].
	state =  4 ifTrue: [self turnOn: {5.}. state :=  5. ^ self].
	state =  5 ifTrue: [self turnOn: {2.}. state :=  6. ^ self].
	state =  6 ifTrue: [self turnOn: {7.}. state :=  7. ^ self].
	state =  7 ifTrue: [self turnOn: {3.}. state :=  8. ^ self].
	state =  8 ifTrue: [self turnOn: {6.}. state :=  9. ^ self].
	
	state =  9 ifTrue: [self turnOff: {1.}. state := 10. ^ self].
	state = 10 ifTrue: [self turnOff: {8.}. state := 11. ^ self].
	state = 11 ifTrue: [self turnOff: {4.}. state := 12. ^ self].
	state = 12 ifTrue: [self turnOff: {5.}. state := 13. ^ self].
	state = 13 ifTrue: [self turnOff: {2.}. state := 14. ^ self].
	state = 14 ifTrue: [self turnOff: {7.}. state := 15. ^ self].
	state = 15 ifTrue: [self turnOff: {3.}. state := 16. ^ self].
	state = 16 ifTrue: [self turnOff: {6.}. state :=  1. ^ self].! !

!PhdExIfKitLEDSpiral methodsFor: 'accessing' stamp: 'pt 6/30/2009 15:14'!
waitTime
	^ 150! !

PhdExIfKitLED subclass: #PhdExIfKitLEDToggle
	instanceVariableNames: 'state'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-Examples'!

!PhdExIfKitLEDToggle commentStamp: 'pt 7/6/2009 16:58' prior: 0!
Makes the two LED axes alternately flash.

This class expects the LED ordered as the following:
    4
    3
8 7   6 5
    2
    1

This example is based on PhdExIfKitLED. Have a look on the comment of that class for further information.!

!PhdExIfKitLEDToggle methodsFor: 'initialize' stamp: 'fs 7/24/2009 15:41'!
initialize

	super initialize.
	state := #1.! !

!PhdExIfKitLEDToggle methodsFor: 'toggle state' stamp: 'fs 7/24/2009 15:41'!
setLEDState

	self turnAllOff.
	state = #1 ifTrue: [self turnOn: {1. 2. 3. 4.}. state := 2. ^ self].
	state = #2 ifTrue: [self turnOn: {5. 6. 7. 8.}. state := 1. ^ self].! !

Object subclass: #PhdExListItem
	instanceVariableNames: 'nextLink value'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-Examples'!

!PhdExListItem commentStamp: 'pt 7/6/2009 16:46' prior: 0!
This is a class used in the PhidgetLab RFID example.
See PhdExRFIDPaint or PhdExTagMap for more information about the example.!

!PhdExListItem class methodsFor: 'as yet unclassified' stamp: 'lk 7/2/2009 22:36'!
new: anObject
	"create a new list item with given object as content."
	
	^ self new
		value: anObject.! !

!PhdExListItem methodsFor: 'accessing' stamp: 'lk 7/2/2009 21:52'!
nextLink

	^ nextLink! !

!PhdExListItem methodsFor: 'accessing' stamp: 'lk 7/2/2009 21:52'!
nextLink: anObject

	nextLink := anObject.! !

!PhdExListItem methodsFor: 'accessing' stamp: 'lk 7/2/2009 21:53'!
value: anObject

	value := anObject.! !

Object subclass: #PhdExSqueakLogoLCD
	instanceVariableNames: 'lcdPhidget'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-Examples'!

!PhdExSqueakLogoLCD methodsFor: 'as yet unclassified' stamp: 'fs 8/12/2009 22:25'!
initialize

	super initialize.
	
	lcdPhidget := PhdCrTextLCD new.! !

!PhdExSqueakLogoLCD methodsFor: 'as yet unclassified' stamp: 'fs 8/12/2009 22:32'!
setCustomChars

	lcdPhidget textLCD 
		setCustomCharAt: 1 toValues: #(542284 4360);
		setCustomCharAt: 2 toValues: #(0 420684);
		setCustomCharAt: 3 toValues: #(0 210342);
		setCustomCharAt: 4 toValues: #(50470 4162);
		setCustomCharAt: 5 toValues: #(397063 8339);
		setCustomCharAt: 6 toValues: #(60720 24);
		setCustomCharAt: 7 toValues: #(552513 3);
		setCustomCharAt: 8 toValues: #(221308 2201).! !

!PhdExSqueakLogoLCD methodsFor: 'as yet unclassified' stamp: 'fs 8/12/2009 22:34'!
setText

	lcdPhidget textLCD
		displayString: 
			(Character codePoint: 8) asString, 
			(Character codePoint: 9) asString, 
			(Character codePoint: 10) asString, 
			(Character codePoint: 11) asString,
			'  I''m a' 
		inRow: 1;
		displayString: 
			(Character codePoint: 12) asString, 
			(Character codePoint: 13) asString, 
			(Character codePoint: 14) asString, 
			(Character codePoint: 15) asString,
			'  Squeeeeaker!!' 
		inRow: 2.! !

!PhdExSqueakLogoLCD methodsFor: 'as yet unclassified' stamp: 'fs 8/12/2009 22:39'!
start

	lcdPhidget openAny.
	lcdPhidget on: #Attach do: [
		self 
			setCustomChars;
			setText.
	].! !

!PhdExSqueakLogoLCD methodsFor: 'as yet unclassified' stamp: 'fs 8/12/2009 22:34'!
stop

	lcdPhidget close.! !

Object subclass: #PhdExStarTrekLCD
	instanceVariableNames: 'running lcdPhidget'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-Examples'!

!PhdExStarTrekLCD commentStamp: 'pt 7/15/2009 08:31' prior: 0!
This is an example for the usage of a Text LCD Phidget (usually bundled with an Interface Kit).

Execute the following line after you've attached the LCD Phidget.

"Create a new example object."
lcd := PhdExTextLCD new.

"Start the demo - this opens a connection to the phidget"
lcd start.

"Stop the demo - this closes the connection to the phidget"
lcd stop.!

!PhdExStarTrekLCD methodsFor: 'initialize' stamp: 'pt 7/15/2009 07:50'!
initialize

	super initialize.
	running := false.
	lcdPhidget := PhdCrTextLCD new.! !

!PhdExStarTrekLCD methodsFor: 'events' stamp: 'fs 7/24/2009 15:52'!
starTrekProcess
	"Let some stars slide along the display.
	 Insiders know where to find it in Star Treck ;)"

	| t |
	t := '          '.
	[ running ] whileTrue: [
		10 to: 1 by: -2 do: [ :i | | k |
			t at: i put: $*; at: i - 1 put: $*.
			k := t , t reverse.
			lcdPhidget textLCD
				displayString: k inRow: 1;
				displayString: k	inRow: 2.
			(Delay forMilliseconds: 500) wait.
			t at: i put: Character space; at: i - 1 put: Character space ] ].! !

!PhdExStarTrekLCD methodsFor: 'events' stamp: 'fs 7/24/2009 15:51'!
start

	running := true.
	lcdPhidget openAny.
	[ self starTrekProcess ] fork! !

!PhdExStarTrekLCD methodsFor: 'events' stamp: 'fs 7/24/2009 15:51'!
stop

	running := false.
	lcdPhidget close.! !

Object subclass: #PhdExTagMap
	instanceVariableNames: 'sensors tags knownTagHandler newTagHandler tagLostHandler'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-Examples'!

!PhdExTagMap commentStamp: 'pt 7/6/2009 16:53' prior: 0!
This is an example about how to use the RFID Phidget from Squeak with PhidgetLab.
This one is more generci than PhdExRFIDPaint and need further programming.

If you give an instance of this class a sensor from an RFID Phidget (PhdCrRFID) it associates an object to each RFID tag. You can specefy the behavior for new/known tags. You might also specify what happens if a tag was found/lost.
To make an instance forget known tags, execute: self forgetTags.

For an example look at PhdExRFIDPaint.!

PhdExTagMap subclass: #PhdExRFIDPaint
	instanceVariableNames: 'rfidPhidget'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-Examples'!

!PhdExRFIDPaint commentStamp: 'pt 7/6/2009 16:54' prior: 0!
This is an example about how to use the Phidget RFID with Squeak/PhidgetLab.

Execute the following in a workspace:
map := PhdExRFIDPaint new. "opens a new instance of this example"
map start. "starts the 'game' and opens a connection to the Phidget"
map stop. "closes the connection - recommended if you want to use this Phidget later. If the connection stays open, the Phidget can not be used somewhere else."!

!PhdExRFIDPaint methodsFor: 'events' stamp: 'fs 7/24/2009 15:47'!
attach
	"Enables the antenna, if I was attached."
	
	rfidPhidget rfidSensor isAntennaOn: true! !

!PhdExRFIDPaint methodsFor: 'initialization' stamp: 'pt 7/6/2009 16:40'!
initialize

	super initialize.
	rfidPhidget := PhdCrRFID new.
	
	"set own handlers that cannot be overwritten."
	newTagHandler := [ :tagString |
		SketchMorph openEditor ].
	
	knownTagHandler := [ :tagString :oldInfo | 
		oldInfo
			openInWorld;
			visible: true;
			yourself ].
	
	tagLostHandler := [ :tagString :oldInfo | 
		oldInfo
			visible: false;
			yourself ].

	"register events"
	rfidPhidget on: #Attach	do: [ self attach ]! !

!PhdExRFIDPaint methodsFor: 'accessing' stamp: 'lk 7/3/2009 12:00'!
knownTagHandler

	^ knownTagHandler! !

!PhdExRFIDPaint methodsFor: 'accessing' stamp: 'lk 7/3/2009 11:45'!
knownTagHandler: aBlock
	"cannot be set in this subclass."! !

!PhdExRFIDPaint methodsFor: 'accessing' stamp: 'lk 7/3/2009 12:00'!
newTagHandler

	^ newTagHandler! !

!PhdExRFIDPaint methodsFor: 'accessing' stamp: 'lk 7/3/2009 11:45'!
newTagHandler: aBlock
	"cannot be set in this subclass."! !

!PhdExRFIDPaint methodsFor: 'as yet unclassified' stamp: 'pt 7/6/2009 16:39'!
start
	"opens a connection to an RFID phidget."
	
	rfidPhidget openAny.
	self
		addSensor: rfidPhidget rfidSensor;
		attach.! !

!PhdExRFIDPaint methodsFor: 'as yet unclassified' stamp: 'pt 7/3/2009 14:22'!
stop
	"close a connection to an RFID phidget."
	
	rfidPhidget close.! !

!PhdExRFIDPaint methodsFor: 'accessing' stamp: 'lk 7/3/2009 12:00'!
tagLostHandler

	^ tagLostHandler! !

!PhdExRFIDPaint methodsFor: 'accessing' stamp: 'lk 7/3/2009 11:45'!
tagLostHandler: aBlock
	"cannot be set in this subclass."! !

!PhdExTagMap methodsFor: 'accessing' stamp: 'lk 7/3/2009 11:31'!
addSensor: anRFIDSensor

	sensors add: (PhdExListItem new: anRFIDSensor).
	anRFIDSensor on: #TagFound do: [ self tagFound: anRFIDSensor ].
	anRFIDSensor on: #TagLost do: [ self tagLost: anRFIDSensor ].! !

!PhdExTagMap methodsFor: 'initialization' stamp: 'pt 7/3/2009 14:40'!
forgetTags
	"clears my tag cache"
	
	tags := Dictionary new.! !

!PhdExTagMap methodsFor: 'initialization' stamp: 'lk 7/3/2009 11:58'!
initialize

	super initialize.
	
	sensors := LinkedList new.
	tags := Dictionary new.! !

!PhdExTagMap methodsFor: 'accessing' stamp: 'lk 7/3/2009 11:59'!
knownTagHandler

	knownTagHandler ifNil: [ 
		knownTagHandler := [ :tagString :oldInfo | oldInfo ] ].

	^ knownTagHandler! !

!PhdExTagMap methodsFor: 'accessing' stamp: 'lk 7/2/2009 23:40'!
knownTagHandler: aBlock
	"aBlock must take 1 argument: the String that represents the found tag we already know.
	When evaluated it must return an object to be associated with that tag."
	
	knownTagHandler := aBlock.! !

!PhdExTagMap methodsFor: 'accessing' stamp: 'lk 7/3/2009 11:59'!
newTagHandler

	newTagHandler ifNil: [
		newTagHandler := [ :tagString | tagString ] ].

	^ newTagHandler! !

!PhdExTagMap methodsFor: 'accessing' stamp: 'lk 7/2/2009 23:39'!
newTagHandler: aBlock
	"aBlock must take 1 argument: the String that represents the newly found tag..
	When evaluated it must return an object to be associated with that tag."
	
	newTagHandler := aBlock.! !

!PhdExTagMap methodsFor: 'accessing' stamp: 'lk 7/2/2009 22:24'!
setTag: aString info: anObject

	tags at: aString asSymbol put: anObject.! !

!PhdExTagMap methodsFor: 'tag handler' stamp: 'lk 7/3/2009 12:05'!
tagFound: anRFIDSensor
	"anRFIDSensor is the sensor which found the tag"
	
	| tagString tagInfo |
	tagString := anRFIDSensor lastTag.
	
	tagInfo := (tags includesKey: tagString asSymbol)
		ifTrue:  [
			self knownTagHandler
				value: tagString
				value: (tags at: tagString asSymbol) ]
		ifFalse: [ self newTagHandler value: tagString ].
	
	self setTag: tagString info: tagInfo.! !

!PhdExTagMap methodsFor: 'tag handler' stamp: 'lk 7/3/2009 11:30'!
tagLost: anRFIDSensor
	"anRFIDSensor is the sensor which lost the tag"
	
	| tagString tagInfo |
	tagString := anRFIDSensor lastTag.
	
	tagInfo := (tags includesKey: tagString asSymbol)
		ifTrue:  [
			tagLostHandler
				value: tagString
				value: (tags at: tagString asSymbol) ]
		ifFalse: [ nil ].
	
	self setTag: tagString info: tagInfo.! !

!PhdExTagMap methodsFor: 'accessing' stamp: 'lk 7/3/2009 12:00'!
tagLostHandler

	tagLostHandler ifNil: [ 
		tagLostHandler := [ :tagString :oldInfo | oldInfo ] ].

	^ tagLostHandler! !

!PhdExTagMap methodsFor: 'accessing' stamp: 'lk 7/3/2009 11:31'!
tagLostHandler: aBlock
	"aBlock must take 2 arguments: the String that represents the lost tag, and its currently set info.
	When evaluated it must return an object to be associated with that tag."
	
	tagLostHandler := aBlock.! !
